@@ -12,13 +12,22 @@ pub trait BinayInsert<T> {
     /// # Warning
     /// This function ***will not*** check if the parsed `vec` is sorted.
     fn binary_insert(&mut self, value: &T);
+    /// The same as `binary_insert`, but doesn't insert a value that is already present.
+    fn binary_insert_no_dup(&mut self, value: T);
 }
 
 impl<T: Ord + Copy> BinayInsert<T> for Vec<T> {
     fn binary_insert(&mut self, value: &T) {
         match self.binary_search(value) {
-            Ok(pos)  => self.insert(pos + 1, value.clone()),
-            Err(pos) => self.insert(pos, value.clone()),
+            Ok(pos)  => self.insert(pos + 1, *value),
+            Err(pos) => self.insert(pos, *value),
+        }
+    }
+
+    fn binary_insert_no_dup(&mut self, value: T) {
+        match self.binary_search(&value) {
+            Ok(_)    => { },
+            Err(pos) => self.insert(pos, value),
         }
     }
 }
\ No newline at end of file
