@@ -1,13 +1,12 @@
 //! Vectors can be really handy, sometimes. Do everything you want with your favorite direction pointing data type from mathematics.
 
-use super::rapidmath::CommonPowers;
+use super::general::{CommonPowers, Increment};
 const INV_DIM: &str = "Error: Dimensions did not match.";
 
 /// Mathematical Vectors in Rust.
 pub struct MathVector {
-    values:    Vec<f64>,
-    dimension: usize,
-    length:    Option<f64>,
+    values: Vec<f64>,
+    length: Option<f64>,
 }
 
 impl MathVector {
@@ -18,10 +17,9 @@ impl MathVector {
     ///
     /// # Returns
     /// A new MathVector.
-    pub fn new(values: &Vec<f64>) -> MathVector {        
-        MathVector { values:    values.clone(),
-                     dimension: values.len(),
-                     length:    None }
+    pub fn new(values: &[f64]) -> MathVector {        
+        MathVector { values: values.to_owned(),
+                     length: None }
     }
     /// Creates a new `MathVector` with the specified capacity.
     ///
@@ -32,31 +30,30 @@ impl MathVector {
     /// A new MathVector with length 0.
     pub fn new_with_dimension(dim: usize) -> MathVector {
 
-        MathVector { values:    vec![0f64; dim],
-                     dimension: dim,
-                     length:    None }
+        MathVector { values: vec![0f64; dim],
+                     length: None }
     }
     /// Gets the dimension in which a `MathVector` lives.
     ///
     /// # Returns
-    /// A `&usize`.
-    pub fn dimension(self: &Self) -> &usize {
-        &self.dimension
+    /// A `usize`.
+    pub fn dimension(&self) -> usize {
+        self.values.len()
     }
     /// Gets the length of a `MathVector`.
     ///
     /// # Returns
     /// A `f64`.
-    pub fn length(self: &mut Self) -> f64 {
+    pub fn length(&mut self) -> f64 {
         match self.length {
-            None          => { let mut len: f64 = 0f64; 
-                               for i in &self.values {
-                                   len += i.square();
-                               }
-                               len = len.sqrt();
-                               self.length = Some(len);
-                               return len;
-                             }
+            None      => { let mut len: f64 = 0f64; 
+                           for i in &self.values {
+                               len.inc_by(i.square());
+                           }
+                           len         = len.sqrt();
+                           self.length = Some(len);
+                           return len;
+                         }
             Some(len) => { return len; }
 
         }
@@ -65,7 +62,7 @@ impl MathVector {
     ///
     /// # Returns
     /// A `&Vec<f64>`.
-    pub fn get_values(self: &Self) -> &'_ Vec<f64> {
+    pub fn get_values(&self) -> &Vec<f64> {
         &self.values
     }
     /// Sets the values of a `MathVector`.
@@ -75,9 +72,9 @@ impl MathVector {
     ///
     /// # Panic
     /// Panics if the values don't have the same dimension as before.
-    pub fn set_values(self: &mut Self, vals: &Vec<f64>) {
-        match vals.len() == self.dimension {
-            true  => { self.values = vals.clone();
+    pub fn set_values(&mut self, vals: &[f64]) {
+        match vals.len() == self.dimension() {
+            true  => { self.values = vals.to_owned();
                        self.length = None; }
             false => { core::panic!("{}", INV_DIM); } 
         }
@@ -87,15 +84,14 @@ impl MathVector {
 impl std::ops::Add for MathVector {
     type Output = Self;
     fn add(self, other: Self) -> MathVector {
-        match self.dimension() == &other.dimension {
+        match self.dimension() == other.dimension() {
             true  =>  { 
-                let mut vals: Vec<f64> = Vec::with_capacity(self.dimension);
-                for i in 0..self.dimension {
+                let mut vals: Vec<f64> = Vec::with_capacity(self.dimension());
+                for i in 0..self.dimension() {
                     vals.push(self.values[i] + other.values[i]);
                 }
-                MathVector { values:    vals,
-                             dimension: self.dimension,
-                             length:    None }
+                MathVector { values: vals,
+                             length: None }
             }
             false => { core::panic!("{}", INV_DIM) }
         }
@@ -107,13 +103,12 @@ impl std::ops::Sub for MathVector {
     fn sub(self, other: Self) -> MathVector {
         match self.dimension() == other.dimension() {
             true  =>  { 
-                let mut vals: Vec<f64> = Vec::with_capacity(self.dimension);
-                for i in 0..self.dimension {
+                let mut vals: Vec<f64> = Vec::with_capacity(self.dimension());
+                for i in 0..self.dimension() {
                     vals.push(self.values[i] - other.values[i]);
                 }
-                MathVector { values:    vals,
-                             dimension: self.dimension,
-                             length:    None }
+                MathVector { values: vals,
+                             length: None }
             }
             false => { core::panic!("{}", INV_DIM) }
         }
@@ -129,14 +124,13 @@ impl std::ops::Sub for MathVector {
     /// A new `MathVector`.
 pub fn scalar_mul(scalar: f64, other: &MathVector) -> MathVector {
 
-    let mut vals: Vec<f64> = Vec::with_capacity(other.dimension);
+    let mut vals: Vec<f64> = Vec::with_capacity(other.dimension());
 
-    for i in 0..other.dimension {
+    for i in 0..other.dimension() {
         vals.push(scalar * other.values[i]);
     }
-    MathVector { values:    vals,
-                 dimension: other.dimension,
-                 length:    None }
+    MathVector { values: vals,
+                 length: None }
 }
 
 /// Creates a new `MathVector` more elegantly from values.
@@ -147,20 +141,22 @@ pub fn scalar_mul(scalar: f64, other: &MathVector) -> MathVector {
 macro_rules! new_mathvec {
     ( $( $a:expr ),* ) => {
         {
-        let mut temp = Vec::new();
-        $(
-            temp.push($a as f64);
-        )*
-        MathVector::new(&temp)
+            let mut temp = Vec::new();
+            $(
+                temp.push($a as f64);
+            )*
+            MathVector::new(&temp)
         }
     };
 }
 
 impl std::fmt::Display for MathVector {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let mut finstring: String = "( ".to_owned();
-        for i in 0..self.dimension {
-            finstring =  " ".to_owned() + &finstring + &self.values[i].to_string() + "; ";
+        let mut finstring: String = String::from("( ");
+        for i in 0..self.dimension() {
+            finstring.push(' ');
+            finstring += &self.values[i].to_string();
+            finstring.push_str("; ");
         }
         finstring.drain(finstring.len()-2..finstring.len());
         write!(f, "{} )", finstring)
